@@ -24,7 +24,7 @@ def out_dist(k):
 
 start = time.time()
 
-model = generate_serial.model(
+model = generate_serial.models(
 
     # group_name='none_800_ma_mp_1',
     # group_name='inPLa2_800_ma_mp_1',
@@ -33,11 +33,18 @@ model = generate_serial.model(
     n_species=20,
     out_dist=out_dist,
     in_dist=in_dist,
+    rxn_prob=[.5, 0, 0, .5],
     # kinetics=['mass_action', 'loguniform', ['kf', 'kr', 'kc'], [[0.01, 100], [0.01, 100], [0.01, 100]]],
+    # kinetics=['gma', 'loguniform', ['kf', 'kr', 'kc', 'ko', 'kor'], [[0.01, 100], [0.01, 100], [0.01, 100],
+    #                                                                  [0.01, 100], [0.01, 100]]],
+    kinetics=['gma', 'lognormal', ['kf', 'kr', 'kc', 'ko', 'kor'], [[0.01, 1], [0.01, 1], [0.01, 1],
+                                                                    [0.01, 1], [1, 1]]],
+    gma_reg=[[.1, .9, 0, 0], .5],
     overwrite=True,
+    rev_prob=.5,
     # ic_params=['uniform', 0, 10],
-    dist_plots=True,
-    net_plots=True
+    # dist_plots=True,
+    # net_plots=True
 
 )
 
