@@ -2,11 +2,25 @@
 import os
 import glob
 
-# dir_name = 'inPLa2_800_ma'
-# dir_name = 'inPLa2_outPLa3_400_ma_5'
-dir_name = 'inPLa2_outPLa3_800_ma_mp_1'
-directory = os.path.join('../models', dir_name, 'antimony')
-print(directory)
+
+dir_name = 'performance50'
+
+counts = []
+for i in range(1000):
+    directory = os.path.join('modelss', dir_name, 'antimony', 'performance50_' + str(i) + '.txt')
+    print(directory)
+    with open(directory) as filee:
+        count = 0
+        lines = filee.readlines()
+        for line in lines:
+            if line[0] == 'J':
+                count += 1
+        counts.append(count)
+
+
+print(sum(counts)/len(counts))
+
+quit()
 files = glob.glob(os.path.join(directory, '*'))
 
 counts = []
