@@ -27,9 +27,9 @@ model_str = generate.model(
     # group_name='none_800_ma_mp_1',
     # group_name='inPLa2_800_ma_mp_1',
     group_name='test',
-    n_species=20,
-    out_dist=out_dist,
-    in_dist=in_dist,
+    n_species=10,
+    # out_dist=out_dist,
+    # in_dist=in_dist,
     # kinetics=['mass_action', 'loguniform', ['kf', 'kr', 'kc'], [[0.01, 100], [0.01, 100], [0.01, 100]]],
     overwrite=True,
     # ic_params=['uniform', 0, 10],
